pub fn plan_statement(stmt: &Stmt) -> StatementPlanExpand description
Build the plan for one top-level statement. Every value is
PlannedValue::Plain except a presented confirm key, which the kernel
redacts unconditionally.
pub fn plan_statement(stmt: &Stmt) -> StatementPlanBuild the plan for one top-level statement. Every value is
PlannedValue::Plain except a presented confirm key, which the kernel
redacts unconditionally.