pub fn parse_string_literal(source: &str) -> Result<String, LexerError>Expand description
Extract the string content from a string token (removes quotes, processes escapes).
pub fn parse_string_literal(source: &str) -> Result<String, LexerError>Extract the string content from a string token (removes quotes, processes escapes).