#[non_exhaustive]pub enum JobStatus {
Running,
Stopped,
Done,
Latched,
Failed,
}Expand description
Status of a background job.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Running
Job is currently running.
Stopped
Job was stopped by a signal (e.g., Ctrl-Z / SIGTSTP).
Done
Job completed successfully.
Latched
Job is blocked on an unfulfilled confirmation latch (exit 2 with a
stored LatchRequest — rm x & under set -o latch). Distinct from
Failed: the op is held, not errored, and can still be fulfilled via
Kernel::confirm with the request surfaced on JobInfo.latch.
Failed
Job failed with an error.