pub fn pipe_stream_default() -> (PipeWriter, PipeReader)Expand description
Create a pipe stream pair with the default capacity (64KB).
pub fn pipe_stream_default() -> (PipeWriter, PipeReader)Create a pipe stream pair with the default capacity (64KB).