Struct VarPath Copy item path Source pub struct VarPath {
pub segments: Vec <VarSegment >,
}Expand description Variable reference path: ${VAR} or ${VAR.field}.
$? resolves to the previous command’s exit code as an int. Field access
on $? is rejected by the validator (use kaish-last for structured data).
Array indexing is not supported — use jq for JSON processing.
Create a simple variable reference with just a name.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Attaches the provided
Context to this type, returning a
WithContext
wrapper.
Read more Attaches the current
Context to this type, returning a
WithContext
wrapper.
Read more Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer.
Read more Mutably dereferences the given pointer.
Read more Drops the object pointed to by the given pointer.
Read more The item yielded by the iterator.
An iterator over the items within this container, by reference.
Iterate over the elements of the container.
Check whether an item is contained within this sequence.
Convert an item of the sequence into a
MaybeRef.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.