pub fn eval_expr(expr: &Expr, scope: &mut Scope) -> EvalResult<Value>Expand description
Convenience function to evaluate an expression with a scope.
Uses NoOpExecutor, so command substitution will fail.
pub fn eval_expr(expr: &Expr, scope: &mut Scope) -> EvalResult<Value>Convenience function to evaluate an expression with a scope.
Uses NoOpExecutor, so command substitution will fail.