value_length

Function value_length 

pub fn value_length(value: &Value) -> i64
Length of a value for ${#…}: element count for a list, key count for a record, and the byte length of the string form for any scalar (unchanged for non-collections). The single source of truth for the three ${#…} evaluation sites (sync + the two async ones).