pub struct Evaluator<'a, E: Executor> { /* private fields */ }Expand description
Expression evaluator.
Evaluates AST expressions to values, using the provided scope for variable lookup and the executor for command substitution.
Implementations