pub struct OutputLimitConfig { /* private fields */ }Expand description
Configurable output size limit.
Threaded through KernelConfig → ExecContext → kernel pipeline execution.
Runtime-mutable via the kaish-output-limit builtin.
Implementations
Sourceimpl OutputLimitConfig
impl OutputLimitConfig
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Whether output limiting is enabled.
Sourcepub fn head_bytes(&self) -> usize
pub fn head_bytes(&self) -> usize
Bytes of output head to preserve in truncated result.
Sourcepub fn tail_bytes(&self) -> usize
pub fn tail_bytes(&self) -> usize
Bytes of output tail to preserve in truncated result.
Sourcepub fn set_head_bytes(&mut self, bytes: usize)
pub fn set_head_bytes(&mut self, bytes: usize)
Set the head preview size.
Sourcepub fn set_tail_bytes(&mut self, bytes: usize)
pub fn set_tail_bytes(&mut self, bytes: usize)
Set the tail preview size.