Parser for kaish source code.
Transforms a token stream from the lexer into an Abstract Syntax Tree. Uses chumsky for parser combinators with good error recovery.
Structs
- Parse
Error - Parse error with location and context.
Functions
- parse
- Parse kaish source code into a Program AST.
- parse_
statement - Parse a single statement (useful for REPL).
Type Aliases
- Span
- Span type used throughout the parser.