Cap’n Proto RPC server for the Kernel (核).
This module implements the Kernel interface defined in schema/kaish.capnp,
allowing remote clients to connect to a kernel via Unix sockets.
Architecture
Client Server
│ │
│─── Unix Socket ────────▶│
│ │
│ Cap'n Proto RPC │
│◀───────────────────────▶│
│ │
│ Kernel │
│ (execute, vars, etc) │Structs
- Kernel
RpcServer - RPC server wrapper around a Kernel.