pub struct PipelineRunner { /* private fields */ }Expand description
Runs pipelines by spawning tasks and connecting them via channels.
Implementations
Sourceimpl PipelineRunner
impl PipelineRunner
Sourcepub fn new(tools: Arc<ToolRegistry>) -> Self
pub fn new(tools: Arc<ToolRegistry>) -> Self
Create a new pipeline runner with the given tool registry.
Sourcepub async fn run(
&self,
commands: &[Command],
ctx: &mut ExecContext,
) -> ExecResult
pub async fn run( &self, commands: &[Command], ctx: &mut ExecContext, ) -> ExecResult
Execute a pipeline of commands.
Each command’s stdout becomes the next command’s stdin. If the pipeline contains scatter/gather, delegates to ScatterGatherRunner. Returns the result of the last command in the pipeline.