Virtual Filesystem (VFS) for kaish.
The VFS provides a unified interface over multiple filesystem backends:
- MemoryFs: In-memory ephemeral storage (for
/v, tests) - LocalFs: Real filesystem access (for mounted worktrees)
- VfsRouter: Routes paths to mounted backends
Design
Kaish kernels own / in their VFS. Backends are mounted at paths:
/ # kernel root
├── /v/ # MemoryFs (blobs, jobs)
├── /mnt/project/ # LocalFs (worktree, rw)
└── /mnt/reference/ # LocalFs (repo, ro)The router finds the longest matching mount point and delegates operations.
Structs
- Builtin
Fs - A read-only filesystem that exposes registered builtins as entries.
- DirEntry
- A directory entry returned by
list. - File
Status - Status of a single file in the working tree.
- GitVfs
- Git-aware filesystem backend.
- JobFs
- Virtual filesystem providing job observability.
- LocalFs
- Local filesystem backend.
- LogEntry
- A single log entry (commit).
- Memory
Fs - In-memory filesystem.
- Metadata
- Metadata about a file or directory.
- Mount
Info - Information about a mount point.
- Status
Summary - Summary of repository status.
- VfsRouter
- Routes filesystem operations to mounted backends.
- Worktree
Info - Information about a worktree.
Enums
- Entry
Type - Type of directory entry.
Traits
- Filesystem
- Abstract filesystem interface.